==> joounit-0.8.4.jar: joo/classes/flexunit/framework/Test.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{*/

   /**
    * A <code>Test</code> can be run, with the results collected.
    *
    * @see TestResult
    */
   "public interface Test extends flexunit.framework.Reflective",1,function($$private){;return[
   /*
     /**
      * Runs the tests, populating the <code>result</code> parameter.
      * @param result The TestResult instance to be populated
      * /
      function runWithResult( result : TestResult ) : void;*/,/*


      /**
      * The number of test cases in this test.
      * @return A Number representing the count of test cases in this test.
      * /
       function countTestCases() : Number;*/,/*

      /**
      * Returns the names of the test methods for this test.
      * @return  Array of method names for this test
      * /
      function getTestMethodNames() : Array;*/,/*

      function toString() : String;*/,
   ];},[],["flexunit.framework.Reflective"], "0.8.0", "0.8.3"
);

==> joounit-0.9.1.jar: joo/classes/flexunit/framework/Test.js <==
joo.classLoader.prepare(/*
   Copyright (c) 2008. Adobe Systems Incorporated.
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:

     * Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
     * Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.
     * Neither the name of Adobe Systems Incorporated nor the names of its
       contributors may be used to endorse or promote products derived from this
       software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
*/

"package flexunit.framework",/*
{*/

   /**
    * A <code>Test</code> can be run, with the results collected.
    *
    * @see TestResult
    */
   "public interface Test extends flexunit.framework.Reflective",1,function($$private){;return[
   /*
     /**
      * Runs the tests, populating the <code>result</code> parameter.
      * @param result The TestResult instance to be populated
      * /
      function runWithResult( result : TestResult ) : void*/,/*


      /**
      * The number of test cases in this test.
      * @return A Number representing the count of test cases in this test.
      * /
       function countTestCases() : Number*/,/*

      /**
      * Returns the names of the test methods for this test.
      * @return  Array of method names for this test
      * /
      function getTestMethodNames() : Array*/,/*

      function toString() : String*/,
   ];},[],["flexunit.framework.Reflective"], "0.8.0", "0.9.1"
);
